@@ -69,7 +69,7 @@ PLNnetworkfamily <- R6Class(
       if (is.null(penalties)) {
         if (control$trace > 1) cat("\n Recovering an appropriate grid of penalties.")
         max_pen <- list_penalty_weights %>%
-          map(~ myPLN$model_par$Sigma / .x) %>%
+          map(~ control$inception$model_par$Sigma / .x) %>%
           map_dbl(~ max(abs(.x[upper.tri(.x, diag = control$penalize_diagonal)]))) %>%
           max()
         penalties <- 10^seq(log10(max_pen), log10(max_pen*control$min_ratio), len = control$n_penalties)
@@ -77,7 +77,7 @@ PLNnetworkfamily <- R6Class(
         if (control$trace > 1) cat("\nPenalties already set by the user")
         stopifnot(all(penalties > 0))
       }
-      ## Sort eh penalty in decreasing order
+      ## Sort the penalty in decreasing order
       o <- order(penalties, decreasing = TRUE)
       private$params <- penalties[o]
       list_penalty_weights <- list_penalty_weights[o]
