@@ -7,6 +7,11 @@ inline arma::vec logfact(arma::mat y) {
     return sum(y % log(y) - y + log(8 * pow(y, 3) + 4 * pow(y, 2) + y + 1. / 30.) / 6. + std::log(M_PI) / 2., 1);
 }
 
+inline arma::mat logfact_mat(arma::mat y) {
+    y.replace(0., 1.);
+    return y % log(y) - y + log(8 * pow(y, 3) + 4 * pow(y, 2) + y + 1. / 30.) / 6. + std::log(M_PI) / 2.;
+}
+
 inline arma::vec ki(arma::mat y) {
     arma::uword p = y.n_cols;
     return -logfact(std::move(y)) + 0.5 * double(p) ;
